@@ -23,13 +23,22 @@ class Node(zodict):
     
     def __setitem__(self, key, val):
         if val.uuid in self._index.keys():
-            raise ValeError(u"Node with uuid already exists")
+            raise ValueError(u"Node with uuid already exists")
         val.__name__ = key
         val.__parent__ = self
         val._index = self._index
         self._index[val.uuid] = val
         zodict.__setitem__(self, key, val)
     
+    def __delitem__(self, key):
+        todelete = self[key]
+        childkeys = todelete.keys()
+        if childkeys:
+            for childkey in childkeys:
+                del todelete[childkey]
+        del self._index[todelete.uuid]
+        zodict.__delitem__(self, key)
+    
     @accepts(object, uuid.UUID)
     def set_uuid(self, uuid):
         if uuid in self._index.keys() and self._index[uuid] is not self:
@@ -65,4 +74,4 @@ class Node(zodict):
         return '<Node object \'%s\' at %s>' % (self.__name__,
                                                hex(id(self))[:-1])
     
-    __str__ = __repr__
\ No newline at end of file
+    __str__ = __repr__
